@@ -6,6 +6,7 @@
  */
 package ajd4jp;
 
+import ajd4jp.format.*;
 import java.math.*;
 import java.util.*;
 
@@ -306,10 +307,11 @@ public enum Holiday implements OffProvider.Off {
 		new FixHoliday( "大正天皇祭", new Holy( 1927, 12, 25 ), new Holy( 1947, 12, 25 ) )
 	),
  
- 	/** <span style="text-decoration:line-through;">即位の礼(1915, 1928)</span> */
+ 	/** 即位の礼(1915, 1928, 2019) */
 	SOKUI(
 		new FixHoliday( "即位の礼", new Holy( 1915, 11, 10 ) ),
-		new FixHoliday( "即位の礼", new Holy( 1928, 11, 10 ) )
+		new FixHoliday( "即位の礼", new Holy( 1928, 11, 10 ) ),
+		new FixHoliday( "天皇の即位の日", new Holy( 2019, 5, 1 ) )
 	),
 	/** <span style="text-decoration:line-through;">大嘗祭(1915, 1928)</span> */
 	ONIE(
@@ -329,6 +331,8 @@ public enum Holiday implements OffProvider.Off {
 	EMP1990( new FixHoliday( "即位の礼正殿の儀", new Holy( 1990, 11, 12 ) ) ),
 	/** <span style="text-decoration:line-through;">徳仁親王の結婚の儀(1993)</span> */
 	EMP1993( new FixHoliday( "徳仁親王の結婚の儀", new Holy( 1993, 6, 9 ) ) ),
+	/** 即位の礼正殿の儀(2019) */
+	EMP2019( new FixHoliday( "即位の礼正殿の儀の行われる日", new Holy( 2019, 10, 22 ) ) ),
 
 	/** 振替休日 */
 	FURIKAE( new Sunday() ),
@@ -424,5 +428,33 @@ public enum Holiday implements OffProvider.Off {
 		}
 		return name;
 	}
+
+	/**
+	 * 指定年の全ての祝日を取得。
+	 * @param yyyy 年。
+	 * @return 祝日の配列。
+	 * @exception AJDException 不正な年。
+	 */
+	public static AJD[] getHoliday(int yyyy) throws AJDException {
+		ArrayList<AJD> list = new ArrayList<AJD>();
+		AJD day = new AJD(yyyy, 1, 1);
+		for (; day.getYear() == yyyy; day = day.addDay(1)) {
+			if (getHoliday(day) != null) { list.add(day); }
+		}
+		return list.toArray(new AJD[0]);
+	}
+
+	/**
+	 * {@link #getHoliday(int)}を呼び出し、結果を標準出力します。
+	 * @param argv 年を指定
+	 * @exception Exception 不正な年。
+	 */
+	public static void main(String[] argv) throws Exception {
+		for (AJD ajd: getHoliday(Integer.parseInt(argv[0]))) {
+			System.out.print(Formats.DATE.toString(ajd));
+			System.out.print("\t");
+			System.out.println(getHoliday(ajd).getName(ajd));
+		}
+	}
 }
 
