@@ -1,6 +1,6 @@
 /*
  * AJD4JP
- * Copyright (c) 2011-2015  Akira Terasaki
+ * Copyright (c) 2011-2017  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に
  * 同意できる場合にのみ利用可能です。
  */
@@ -49,6 +49,7 @@ public class Month implements Comparable<Month>, java.io.Serializable {
 	 * コンストラクタ。
 	 * @param yyyy 年。0は指定できません。BC1年は-1です。
 	 * @param mm 月。1～12。
+	 * @throws AJDException 不正な年月。
 	 */
 	public Month( int yyyy, int mm ) throws AJDException {
 		init( yyyy, mm );
@@ -143,6 +144,29 @@ public class Month implements Comparable<Month>, java.io.Serializable {
 		return isLeapYear( y );
 	}
 
+	/**
+	 * 月の初日取得。
+	 * @return その月の1日を返します。
+	 */
+	public AJD getFirstAJD() {
+		try {
+			return new AJD(y, m, 1);
+		}
+		catch(Exception e){}
+		return null;
+	}
+	/**
+	 * 月の最終日取得。
+	 * @return 1月なら31。2月は閏年判定を行います。
+	 */
+	public AJD getLastAJD() {
+		try {
+			return new AJD(y, m, getLastDay());
+		}
+		catch(Exception e){}
+		return null;
+	}
+
 	/**
 	 * 月の最終日取得。
 	 * @param yyyy 年。
